@@ -1,8 +1,4 @@
-//! # Indentasy
-//!
-//! Indent like a party
-//!
-//! Rust implementation of https://cwestblog.com/2014/01/02/javascript-indenting-text/
+#![doc = include_str!("../README.md")]
 
 use regex::Regex;
 
@@ -11,51 +7,44 @@ use regex::Regex;
 /// # Examples
 ///
 /// ```rust
-/// #[cfg(test)]
-/// mod tests {
-///     #[test]
-///     fn hello_newline_world() {
-///         assert_eq!("    hello\n    world", crate::indent::indent("hello\nworld", 1, 4));
-///     }
+/// fn hello_newline_world() {
+///     assert_eq!("    hello\n    world", indentasy::indent("hello\nworld", 1, 4));
+/// }
 ///
-///     #[test]
-///     fn newline_hello_newline_world() {
-///         assert_eq!(
-///             "\n    hello\n    world",
-///             crate::indent::indent("\nhello\nworld", 1, 4)
-///         );
-///     }
+/// fn newline_hello_newline_world() {
+///     assert_eq!(
+///         "\n    hello\n    world",
+///         indentasy::indent("\nhello\nworld", 1, 4)
+///     );
+/// }
 ///
-///     #[test]
-///     fn hello_newline_world_indent_with_tab() {
-///         assert_eq!("\thello\n\tworld", crate::indent::indent("hello\nworld", 1, 0));
-///     }
+/// fn hello_newline_world_indent_with_tab() {
+///     assert_eq!("\thello\n\tworld", indentasy::indent("hello\nworld", 1, 0));
+/// }
 ///
-///     #[test]
-///     fn hello_newline_world_with_String() {
-///         assert_eq!(
-///             "    hello\n    world",
-///             crate::indent::indent("hello\nworld".to_string(), 1, 4)
-///         );
-///     }
+/// fn hello_newline_world_with_String() {
+///     assert_eq!(
+///         "    hello\n    world",
+///         indentasy::indent("hello\nworld".to_string(), 1, 4)
+///     );
 /// }
 /// ```
-pub fn indent<S: Into<String>>(s: S, num_of_indents: usize, spaces_per_indent: usize) -> String {
-    let s = s.into();
+pub fn indent<S: AsRef<str>>(s: S, num_of_indents: usize, spaces_per_indent: usize) -> String {
     let s = s
+        .as_ref()
         .lines()
         .enumerate()
-        .map(|(i, ss)| {
+        .map(|(i, line)| {
             let tmp;
             [
                 if i > 0 { "\n" } else { "" },
-                if !ss.is_empty() {
+                if !line.is_empty() {
                     tmp = vec![""; num_of_indents + 1].join("\t");
                     &tmp
                 } else {
-                    ss
+                    ""
                 },
-                ss,
+                line,
             ]
             .concat()
         })
